
### PART I. Randomized Block ANOVA Design ###

## read and attach the data for the randomized block example
block_data <- read.table("Tribolium.txt", header=T)
attach(block_data)

## use the factor() function to tag blocks as a categorical variable
block <- factor(blocks)

## create and execute the randomized block ANOVA model
block_model <- lm(dryweight ~ genotype + block)
anova(block_model)

## calculate relative efficiency
MS <- anova(block_model)
msb <-MS[1,3]
mserb <-MS[3,3] 
msecr <- (3*msb+4*2*mserb)/(4*3-1)
msecr
RE <- (100*msecr)/mserb
RE

## detach the data for the randomized block example
detach(block_data)

### PART II. Nested ANOVA Design ###

## read and attach the data for the nested example
nested_data <- read.table("pollination.txt", header=T)
attach(nested_data)

## use the factor() function to tag replicate as a categorical variable
rep <- factor(replicate)

## create and execute the nested ANOVA model
nested_model <- lm(seeds ~ treatment/rep)
anova(nested_model)

## to construct the proper F-ratio, we need the anova() return value
nested_anova <- anova(nested_model)

## construct F-ratio: (MS_among_groups/MS_among_replicates)
MS_among_groups <- nested_anova[1,3]
MS_among_replicates <- nested_anova[2,3]
F_ratio <- MS_among_groups/MS_among_replicates
F_ratio

## Alternately, we can average the subsamples and re-run as 1-way ANOVA

## first, create a list of the grouping variables for the aggregate() function
aggregate_list <- list("treatment"=treatment, "replicate"=rep)

## second, calculate the replicate means using aggregate()
replicate_means <- aggregate(seeds, by=aggregate_list, FUN=mean)

## finally, do the analysis again as a one-way ANOVA
oneway_model <- lm(replicate_means$x ~ replicate_means$treatment)
anova(oneway_model)

## detach the data for the randomized block example
detach(nested_data)
